@@ -7,7 +7,7 @@
 ## This code is free software; you can redistribute it and/or modify
 ## it under the same terms as Perl itself.
 ##
-## $Id: RSA.pm,v 1.45 2001/06/11 13:41:55 vipul Exp $
+## $Id: RSA.pm,v 1.46 2001/06/18 14:37:48 vipul Exp $
 
 package Crypt::RSA;
 use lib '/home/vipul/PERL/crypto/rsa/lib';
@@ -22,7 +22,7 @@ use Convert::ASCII::Armour;
 use Carp;
 
 @ISA = qw(Class::Loader Crypt::RSA::Errorhandler);
-($VERSION) = '$Revision: 1.45 $' =~ /\s(\d+\.\d+)\s/; 
+($VERSION) = '$Revision: 1.46 $' =~ /\s(\d+\.\d+)\s/; 
 
 
 my %DEFAULTS = ( 
@@ -44,7 +44,7 @@ my %KNOWNMAP = (
 
              PSS_SS =>  { Module => "Crypt::RSA::SS::PSS"       },
         PKCS1v21_SS =>  { Module => "Crypt::RSA::SS::PSS"       },
-      PKCS1v15SS_SS =>  { Module => "Crypt::RSA::SS::PKCS1v15"  },
+        PKCS1v15_SS =>  { Module => "Crypt::RSA::SS::PKCS1v15"  },
 
   # POST PROCESSORS
 
@@ -92,6 +92,9 @@ sub encrypt {
     my $plaintext         = $params{Message};
     my $key               = $params{Key}; 
 
+    return $self->error ($key->errstr, \%params, $key, \$plaintext) 
+        unless $key->check();
+
     my $cyphertext;
     my @segments = steak ($plaintext, 
                           blocksize (
@@ -125,6 +128,8 @@ sub decrypt {
     my $cyphertext       = $params{Cyphertext};
     my $key              = $params{Key}; 
 
+    return $self->error ($key->errstr, \%params, $key) unless $key->check();
+
     if ($params{Armour} || $params{Armor}) { 
         my $decoded = $self->{pp}->unarmour ($cyphertext) ||
             return $self->error ($self->{pp}->errstr());
@@ -205,8 +210,8 @@ Crypt::RSA - RSA public-key cryptosystem.
 
 =head1 VERSION
 
- $Revision: 1.45 $ (Beta)
- $Date: 2001/06/11 13:41:55 $
+ $Revision: 1.46 $ (Beta)
+ $Date: 2001/06/18 14:37:48 $
 
 =head1 SYNOPSIS
 
